@@ -114,7 +114,7 @@ sites_to_parse = {
 	
 	"Code Project": { # www.codeproject.com
 		"module": codeproject,
-		"kwargs": {'categories': ['all']}
+		"kwargs": {'categories': ['all']} # 'web', 'android', 'c#', 'c++' and 'ios'
 	},
 	
 	"Hacker News": { # news.ycombinator.com
@@ -199,7 +199,7 @@ sites_to_parse = {
 	
 	"ZDNet": { # www.zdnet.com
 		"module": zdnet,
-		"kwargs": {}
+		"kwargs": {'categories': ['all']} # 'news', 'reviews' and 'downloads'
 	},
 		
 	"Geektimes": { # geektimes.ru
@@ -218,6 +218,12 @@ filters = {
 	}
 }
 
+# Words that you're interested in
+interesting_words = {}
+
+# Words that you find boring
+boring_words = {}
+
 update_interval = 1800 # Parse articles every 30 minutes
 
 # Database for keeping history
